# 1.0

import configparser

cfg = configparser.ConfigParser()
Link = "https://github.com/ivan-software/Ini-Reader/"

class INIReader:
    def IniRead(FILE):
        global cfg
        file = FILE
        cfg.read(file)
    def Read(BLOCK, VARIABLE, PRINT=1):
        global cfg
        block = BLOCK
        var = VARIABLE
        read = cfg[block][var]
        if PRINT == 1:
            print(read)
        if PRINT == 0:
            read = cfg[block][var]
    def Help():
        print(
        "IniRead - Read INI \n "
      	"Read - Read And Print INI \n "
      	"If PRINT = 0 - Data Will Not Print \n "
      	"If PRINT = 1 - Data Prints \n "
        "More on " + Link
        )


#-----/*\----------/*\----------/*\-----
__package__ = "INI-Reader"
__version__ = "1.0"
__author__ = "Ivan Perzhinskiy"
__mask__ = "ini_reader"
#-----/*\----------/*\----------/*\-----



import setuptools

with open(r'readme.md', 'r', encoding='utf-8') as fh:
	long_description = fh.read()

setuptools.setup(
	name='ini-reader',
	version='1.0',
	author='IonE',
	author_email='ivanaperginsky@gmail.com',
	description='Ini Reader For Python',
	long_description=long_description,
	long_description_content_type='text/markdown',
	packages=['Ini-Reader'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License ",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)